@@ -1,10 +1,22 @@
+import json
+
 
 class HTTPException(Exception):
     message: str
     code: int
 
+    def __init__(self, msg=None):
+        if msg:
+            self.msg = msg
+
     def pack(self):
-        return dict(error=self.message), self.code
+        return dict(error=self.message, msg=getattr(self, 'msg', '')), self.code
+
+    def __str__(self):
+        return self.message
+
+    def __dict__(self):
+        return self.pack()
 
 
 class HTTPClientError(HTTPException):
@@ -16,6 +28,11 @@ class HTTPNotAcceptable(HTTPException):
     message = 'This request is not acceptable'
 
 
+class HTTPNotProcessable(HTTPException):
+    code = 422
+    message = 'Request cannot be processed.'
+
+
 class HTTPNotFound(HTTPException):
     code = 404
     message = 'Resource does not exist'
